==> pips-spr200_210-2.6.2.tar.gz: pips-spr200_210-2.6.2/src/pipsDef.h <==
/*
 * Photo Image Print System
 * Copyright (C) 2000-2004 EPSON KOWA Corporation.
 * Copyright (C) SEIKO EPSON CORPORATION 2000-2004.
 *
 *  This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * As a special exception, EPSON KOWA Corporation gives permission to
 * link the code of this program with libraries which are covered by
 * the EPSON KOWA PUBLIC LICENCE and distribute their linked
 * combinations.  You must obey the GNU General Public License in all
 * respects for all of the code used other than the libraries which
 * are covered by EPSON KOWA PUBLIC LICENCE.
 */
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#ifndef __PIPSDEF_H__
#define __PIPSDEF_H__

/* dependency */

/* 4դդ̵Ԥʤ */
#if (PM900C)      || (PM880C)   || (PM780C)   || (PM3500C)   || (PM790PT) \
 || (PM920C)      || (PM780CS)  || (PM820CUG) || (PM3300CUG) || (SP810_820) \
 || (PM730C)      || (PM830C)   || (PM890C)   || (PM950C)    || (PM850PT) \
 || (PM840C)      || (SP960)    || (SP925)    || (PM740C)    || (PM740DU) \
 || (PM870C)      || (PM860PT)  || (PM930C)   || (PXV700)    || (SP830U) \
 || (SP2100_2200) || (PM4000PX) || (PM3700C)  || (PM940C)    || (PM980C) || (PMG700) \
 || (SC64_63S)    || (PXV600)   || (PMG800)   || (CC600PX)   || (PMA850) || (PMD750) \
 || (SC84_83S)    || (SCX5300_5400S) || (SPR300_310) || (SPR200_210)
#define USE_AUTO_TRIM_4
#endif

/* ϲ240dpiѤ뵡 */
#if (SC580) || (SC480) || (SC40S) || (SC20S) || (SC41_42S) || (SC43S)
#define USE_RESOLUTION_240
#endif

/* ȥåȤɸƤ뵡 */
#if (PM850PT) || (SP925) || (PM860PT)
#define USE_AUTO_CUT
#endif

/* 󥯥󥸥ƥбƤ뵡 */
#if (SP2100_2200) || (PM4000PX) || (PM980C)
#define INK_CHANGE_SYSTEM
#endif

/* ɥեȰβ٤360dpiǤ뵡 */
#if (PM950C) || (SP960) || (SP2100_2200) || (PM4000PX) || (PM980C) || (PMG800)
#define USE_360_DRAFT
#endif

/* ɥեȰβ٤180dpiǤ뵡 */
#if (PM760C) || (PM750_2000C) || (PM2200C) || (PM900C) || (PM670C) \
 || (SC980)  || (PM920C)      || (SC70S)   || (SC80S)  || (SC82S) \
 || (PXV700) || (PM940C)      || (PXV600)  || (CC600PX)|| (SC84_83S) \
 || (SCX5100_5200S) || (SCX5300_5400S)
#define USE_180_DRAFT
#endif

/* Υ󥯤ѤƤ뵡 */
#if (SC70S)       || (SC80S) || (PM950C) || (SP960) || (PXV700) \
 || (SP2100_2200) || (PM4000PX)
#define USE_INKBOX
#endif


/* Print Mode */
#ifdef INK_CHANGE_SYSTEM
#define MODE_ITEM 7
#else
#define MODE_ITEM 6
#endif /* INK_CHANGE_SYSTEM */


enum MODE_OFSET
{
	MOFS_MEDIA = 0,
	MOFS_INPUT,
	MOFS_HALFTONE,
	MOFS_MICRO_WEAVE,
	MOFS_HIGH_SPEED,
#ifdef INK_CHANGE_SYSTEM
	MOFS_INKSET,
#endif /* INK_CHANGE_SYSTEM */
	MOFS_QUALITY
};

/* output type */
enum eOUTPUT_FORMAT
{
  PIPS_OUTPUT_MONO = 0,
  PIPS_OUTPUT_CMYKcm
};

/* ink set */
/* PIPS_INKSET_DEFAULT  */
enum eINKSET
{
  PIPS_INKSET_CMYK = 1,
  PIPS_INKSET_CMYKcm,
  PIPS_INKSET_CMYKcmDY,
  PIPS_INKSET_CMYKcmLk,
  PIPS_INKSET_CMYcmMkLk,
  PIPS_INKSET_CMYcmMk
};

/* media size */
enum ePAPER_SIZE
{
  PIPS_PAPER_LETTER = 0,
  PIPS_PAPER_LEGAL,
  PIPS_PAPER_A3,
  PIPS_PAPER_A3_PLUS,
  PIPS_PAPER_A4,
  PIPS_PAPER_A5,
  PIPS_PAPER_B4,
  PIPS_PAPER_B5,
  PIPS_PAPER_A6_INDEX,
  PIPS_PAPER_POSTCARD_SNGL,
  PIPS_PAPER_POSTCARD_DBL,
  PIPS_PAPER_PHOTO_PRINT,
  PIPS_PAPER_JENV_CHOU3,
  PIPS_PAPER_JENV_CHOU4,
  PIPS_PAPER_JENV_YOU1,
  PIPS_PAPER_JENV_YOU2,
  PIPS_PAPER_JENV_YOU3,
  PIPS_PAPER_JENV_YOU4,
  PIPS_PAPER_TRIM_4X6,
  PIPS_PAPER_TRIM_L,
  PIPS_PAPER_TRIM_NAMECARD,
  PIPS_PAPER_TRIM_2L,
  PIPS_PAPER_TRIM_LL,
  PIPS_PAPER_EXECUTIVE,
  PIPS_PAPER_HALF_LETTER,
  PIPS_PAPER_INDEXCARD5,
  PIPS_PAPER_INDEXCARD8,
  PIPS_PAPER_ENV_10,
  PIPS_PAPER_ENV_DL,
  PIPS_PAPER_ENV_C6,
  PIPS_PAPER_ENV_FOR5X8,
  PIPS_PAPER_PHOTO_100x150,
  PIPS_PAPER_PHOTO_200x300,
  PIPS_PAPER_4X6FULL,
  PIPS_PAPER_PANORAMIC,

  PIPS_PAPER_CREDITCARD,
  PIPS_PAPER_BUSINESS_CARD,

};


/* media type */
enum eMEDIA_TYPE
{
  PIPS_MED_PLAIN = 0,
  PIPS_MED_COATED360,
  PIPS_MED_COATED720,
  PIPS_MED_TRANSPARENCY,
  PIPS_MED_GLOSSYFILM,
  PIPS_MED_GLOSSYPAPER,
  PIPS_MED_BACKPRINT,
  PIPS_MED_IRON_PRINT = 14,
  PIPS_MED_RC_PHOTO = 18,
  PIPS_MED_MATT_HEAVY = 23,
  PIPS_MED_CD_R = 35,
  PIPS_MED_MAT_BOARD = 37,
  PIPS_MED_NEW_SF = 46,
  PIPS_MED_CLPP = 51,
  PIPS_MED_BWIP,
  PIPS_MED_DBS_MATTE,
  PIPS_MED_ARCHIVALMATTE,
  PIPS_MED_PSEMIGLOSS,
  PIPS_MED_PHOTOWEIGHT,
  PIPS_MED_ESF,
  PIPS_MED_EPP,
  PIPS_MED_IJPC,
 
  PIPS_MED_RCPC,  
  PIPS_MED_GLOSSYPHOTOPAPER,
  PIPS_MED_MCLP,
  PIPS_MED_WATERCOLOR,
  PIPS_MED_ERC,

  PIPS_MED_EPM,
  PIPS_MED_EDMP,
  PIPS_MED_EPS,
  PIPS_MED_EIRON_PRINT,

  PIPS_MED_EPP_P,
  PIPS_MED_BWP,

  PIPS_MED_RPPC,
  PIPS_MED_ERC_S,
  PIPS_MED_EGPP,

  PIPS_MED_EOHP,              
  PIPS_MED_P_BOARD,     
 
  PIPS_MED_PLAIN_SPEED 	// special media.
 
};

/* Ųѥޥ	 */
/* PISP_MED_XXX |   	 */
#define	SILENT_MASK 0x10000000	



/* micro weave */
enum eMICRO_WEAVE
{
  PIPS_MW_OFF = 0,
  PIPS_MW_ON
};

/* high speed */
enum eHIGH_SPEED
{
  PIPS_HS_OFF = 0,
  PIPS_HS_ON
};

/* color mode */
enum eCOLOR_MODE
{
  PIPS_CMM_PHOTO = 0,
  PIPS_CMM_GRAPH,
  PIPS_CMM_AUTO,
  PIPS_CMM_NONE
};

/* halftone */
enum eHALFTONE
{
  PIPS_HT_QUALITY = 0,
  PIPS_HT_SPEED,
  PIPS_HT_NONE
};

/* feeder */
enum eFEEDER
{
  PIPS_BIN_AUTO = 0,
  PIPS_BIN_USER,
  PIPS_BIN_TRIMBANNER,
  PIPS_BIN_AUTO_TRIM,
  PIPS_BIN_AUTO_TRIM_4,
  PIPS_BIN_AUTO_EX, 
  PIPS_BIN_MANUAL,       
  PIPS_BIN_MANUAL_TRIM
};

/* quality level set pattern bits */
enum eQUALITY
{
#if (HIGH_RESOLUTION == 0)

#ifdef USE_360_DRAFT
  PIPS_LV_DRAFT = 10,
  PIPS_LV_STD = 1,
#else
  PIPS_LV_DRAFT = 0,
  PIPS_LV_STD,
#endif /* USE_360_DRAFT */
  PIPS_LV_FINE,
  PIPS_LV_SFINE,
  PIPS_LV_PHOTO,
  PIPS_LV_SPHOTO,

#elif(HIGH_RESOLUTION == 1)

/*   */
#ifdef USE_360_DRAFT
  PIPS_LV_DRAFT = 10,
  PIPS_LV_STD360 = 1,
#else
  PIPS_LV_DRAFT = 0,
  PIPS_LV_STD360,
#endif /* USE_360_DRAFT */
  PIPS_LV_FINE720,
  PIPS_LV_SFINE720,
  PIPS_LV_PHOTO1440,
  PIPS_LV_PHOTO2880,
  PIPS_LV_SPHOTO2880,

#else

/* 2  */
#ifdef USE_360_DRAFT
  PIPS_LV_DRAFT = 10,
  PIPS_LV_STD360 = 1,
#else
  PIPS_LV_DRAFT = 0,
  PIPS_LV_STD360,
#endif /* USE_360_DRAFT */
  PIPS_LV_FINE720,
  PIPS_LV_SFINE720,
  PIPS_LV_PHOTO1440,
  PIPS_LV_PHOTO2880,
  PIPS_LV_SPHOTO1440,
  PIPS_LV_SPHOTO2880,

#endif
  
/* 2003.05 Added */
  PIPS_LV_SILENT

};

/* Ink status */
enum eINK_STATUS
{
  ST_INK_NORMAL = 0,
  ST_INK_LOW,
  ST_INK_END
};

/* Fit to page */
enum eFIT_PAGE
{
	PIPS_FP_OFF = 0,
	PIPS_FP_ON
};

/* Multi page */
enum eMULTI_PAGE
{
	PIPS_MP_1 = 0,
	PIPS_MP_2,
	PIPS_MP_4
};

/* Auto cut */
enum eAUTO_CUT
{
	PIPS_CP_NONE = 0,
	PIPS_CP_1,
	PIPS_CP_2
};


#ifndef __PIPS_DEF_H__
typedef unsigned int UINT;
typedef unsigned short USHORT;
typedef unsigned long ULONG;
typedef unsigned char UCHAR;
typedef struct tagPOINT
{
  long  x;
  long  y;
} POINT, *PPOINT, *LPPOINT;
#endif /* __PIPS_DEF_H__ */

typedef int (*func_t)(UCHAR *, void *, void *, void *);


#endif /* __PIPSDEF_H__ */

==> pips-spr800-2.6.2.tar.gz: pips-spr800-2.6.2/src/pipsDef.h <==
/*
 * Photo Image Print System
 * Copyright (C) 2000-2004 EPSON KOWA Corporation.
 * Copyright (C) SEIKO EPSON CORPORATION 2000-2004.
 *
 *  This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * As a special exception, EPSON KOWA Corporation gives permission to
 * link the code of this program with libraries which are covered by
 * the EPSON KOWA PUBLIC LICENCE and distribute their linked
 * combinations.  You must obey the GNU General Public License in all
 * respects for all of the code used other than the libraries which
 * are covered by EPSON KOWA PUBLIC LICENCE.
 */
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#ifndef __PIPSDEF_H__
#define __PIPSDEF_H__

/* dependency */

/* 4դդ̵Ԥʤ */
#if (PM900C)      || (PM880C)   || (PM780C)   || (PM3500C)   || (PM790PT) \
 || (PM920C)      || (PM780CS)  || (PM820CUG) || (PM3300CUG) || (SP810_820) \
 || (PM730C)      || (PM830C)   || (PM890C)   || (PM950C)    || (PM850PT) \
 || (PM840C)      || (SP960)    || (SP925)    || (PM740C)    || (PM740DU) \
 || (PM870C)      || (PM860PT)  || (PM930C)   || (PXV700)    || (SP830U) \
 || (SP2100_2200) || (PM4000PX) || (PM3700C)  || (PM940C)    || (PM980C) || (PMG700) \
 || (PXG900)   \
 || (SC64_63S)    || (PXV600)   || (PMG800)   || (CC600PX)   || (PMA850) || (PMD750) \
 || (SC84_83S)    || (SCX5300_5400S) || (SPR300_310) || (SPR200_210) || (SPRX600_610)\
 || (SPRX500_510) || (SCX6300_6400S) || (PXV500) || (SPR800) || (SC65_66S) || (SC85_86S)
#define USE_AUTO_TRIM_4
#endif

/* ϲ240dpiѤ뵡 */
#if (SC580) || (SC480) || (SC40S) || (SC20S) || (SC41_42S) || (SC43S) || (SC45_46S)
#define USE_RESOLUTION_240 1
#endif

/* ȥåȤɸƤ뵡 */
#if (PM850PT) || (SP925) || (PM860PT)
#define USE_AUTO_CUT
#endif

/* 󥯥󥸥ƥбƤ뵡 */
#if (SP2100_2200) || (PM4000PX) || (PM980C)
#define INK_CHANGE_SYSTEM
#endif

/* ɥեȰβ٤360dpiǤ뵡 */
#if (PM950C) || (SP960) || (SP2100_2200) || (PM4000PX) || (PM980C) || (PMG800) || (PXG900) \
 || (SPR800)
#define USE_360_DRAFT
#endif

/* ɥեȰβ٤180dpiǤ뵡 */
#if (PM760C) || (PM750_2000C) || (PM2200C) || (PM900C) || (PM670C) \
 || (SC980)  || (PM920C)      || (SC70S)   || (SC80S)  || (SC82S) \
 || (PXV700) || (PM940C)      || (PXV600)  || (CC600PX)|| (SC84_83S) \
 || (SCX5100_5200S) || (SCX5300_5400S) || (SCX6300_6400S) || (SC85_86S)
#define USE_180_DRAFT
#endif

/* Υ󥯤ѤƤ뵡 */
#if (SC70S)       || (SC80S) || (PM950C) || (SP960) || (PXV700) \
 || (SP2100_2200) || (PM4000PX)
#define USE_INKBOX
#endif


/* Print Mode */
#ifdef INK_CHANGE_SYSTEM
#define MODE_ITEM 7
#else

#if CLEAR_INK
#define MODE_ITEM 7
#else
#define MODE_ITEM 6
#endif /* CLEAR_INK */

#endif /* INK_CHANGE_SYSTEM */


enum MODE_OFSET
{
	MOFS_MEDIA = 0,
	MOFS_INPUT,
	MOFS_HALFTONE,
	MOFS_MICRO_WEAVE,
	MOFS_HIGH_SPEED,
#ifdef INK_CHANGE_SYSTEM
	MOFS_INKSET,
#endif /* INK_CHANGE_SYSTEM */
#if CLEAR_INK
	/* 2004.01.24 Clear Ink */
	/* CLEAR_INK is 1 or 0  */
	MOFS_QUALITY,
	MOFS_CLEAR_INK
#else
 	MOFS_QUALITY
#endif
	
};

/* output type */
enum eOUTPUT_FORMAT
{
  PIPS_OUTPUT_MONO = 0,
  PIPS_OUTPUT_CMYKcm
};

/* ink set */
/* PIPS_INKSET_DEFAULT  */
enum eINKSET
{
  PIPS_INKSET_CMYK = 1,
  PIPS_INKSET_CMYKcm,
  PIPS_INKSET_CMYKcmDY,
  PIPS_INKSET_CMYKcmLk,
  PIPS_INKSET_CMYcmMkLk,
  PIPS_INKSET_CMYcmMk,
  PIPS_INKSET_CMYKRVCl,		/* 2004.01.22 New Ink */
  PIPS_INKSET_CMYKRV		/* 2004.01.22 New Ink */  
  
};

/* media size */
enum ePAPER_SIZE
{
  PIPS_PAPER_LETTER = 0,
  PIPS_PAPER_LEGAL,
  PIPS_PAPER_A3,
  PIPS_PAPER_A3_PLUS,
  PIPS_PAPER_A4,
  PIPS_PAPER_A5,
  PIPS_PAPER_B4,
  PIPS_PAPER_B5,
  PIPS_PAPER_A6_INDEX,
  PIPS_PAPER_POSTCARD_SNGL,
  PIPS_PAPER_POSTCARD_DBL,
  PIPS_PAPER_PHOTO_PRINT,
  PIPS_PAPER_JENV_CHOU3,
  PIPS_PAPER_JENV_CHOU4,
  PIPS_PAPER_JENV_YOU1,
  PIPS_PAPER_JENV_YOU2,
  PIPS_PAPER_JENV_YOU3,
  PIPS_PAPER_JENV_YOU4,
  PIPS_PAPER_TRIM_4X6,
  PIPS_PAPER_TRIM_L,
  PIPS_PAPER_TRIM_NAMECARD,
  PIPS_PAPER_TRIM_2L,
  PIPS_PAPER_TRIM_LL,
  PIPS_PAPER_EXECUTIVE,
  PIPS_PAPER_HALF_LETTER,
  PIPS_PAPER_INDEXCARD5,
  PIPS_PAPER_INDEXCARD8,
  PIPS_PAPER_ENV_10,
  PIPS_PAPER_ENV_DL,
  PIPS_PAPER_ENV_C6,
  PIPS_PAPER_ENV_FOR5X8,
  PIPS_PAPER_PHOTO_100x150,
  PIPS_PAPER_PHOTO_200x300,
  PIPS_PAPER_4X6FULL,
  PIPS_PAPER_PANORAMIC,

  PIPS_PAPER_CREDITCARD,
  PIPS_PAPER_BUSINESS_CARD,

};


/* media type */
enum eMEDIA_TYPE
{
  PIPS_MED_PLAIN = 0,
  PIPS_MED_COATED360,
  PIPS_MED_COATED720,
  PIPS_MED_TRANSPARENCY,
  PIPS_MED_GLOSSYFILM,
  PIPS_MED_GLOSSYPAPER,
  PIPS_MED_BACKPRINT,
  PIPS_MED_IRON_PRINT = 14,
  PIPS_MED_RC_PHOTO = 18,
  PIPS_MED_MATT_HEAVY = 23,
  PIPS_MED_CD_R = 35,
  PIPS_MED_MAT_BOARD = 37,
  PIPS_MED_NEW_SF = 46,
  PIPS_MED_CLPP = 51,
  PIPS_MED_BWIP,
  PIPS_MED_DBS_MATTE,
  PIPS_MED_ARCHIVALMATTE,
  PIPS_MED_PSEMIGLOSS,
  PIPS_MED_PHOTOWEIGHT,
  PIPS_MED_ESF,
  PIPS_MED_EPP,
  PIPS_MED_IJPC,
 
  PIPS_MED_RCPC,  
  PIPS_MED_GLOSSYPHOTOPAPER,
  PIPS_MED_MCLP,
  PIPS_MED_WATERCOLOR,
  PIPS_MED_ERC,

  PIPS_MED_EPM,
  PIPS_MED_EDMP,
  PIPS_MED_EPS,
  PIPS_MED_EIRON_PRINT,

  PIPS_MED_EPP_P,
  PIPS_MED_BWP,

  PIPS_MED_RPPC,
  PIPS_MED_ERC_S,
  PIPS_MED_EGPP,

  PIPS_MED_EOHP,              
  PIPS_MED_P_BOARD,     

  PIPS_MED_ADDRESSSIDE,
  PIPS_MED_SF_POSTCARD,
 
  PIPS_MED_PLAIN_SPEED,	// special media.
  PIPS_MED_PLAIN_BKSAVE // special media. Black Ink Save Mode 2004.3.231 add
 
};

/* Ųѥޥ	 */
/* PISP_MED_XXX |   	 */
#define	SILENT_MASK 0x10000000	



/* micro weave */
enum eMICRO_WEAVE
{
  PIPS_MW_OFF = 0,
  PIPS_MW_ON
};

/* high speed */
enum eHIGH_SPEED
{
  PIPS_HS_OFF = 0,
  PIPS_HS_ON
};

/* color mode */
enum eCOLOR_MODE
{
  PIPS_CMM_PHOTO = 0,
  PIPS_CMM_GRAPH,
  PIPS_CMM_AUTO,
  PIPS_CMM_NONE
};

/* halftone */
enum eHALFTONE
{
  PIPS_HT_QUALITY = 0,
  PIPS_HT_SPEED,
  PIPS_HT_NONE
};

/* feeder */
enum eFEEDER
{
  PIPS_BIN_AUTO = 0,
  PIPS_BIN_USER,
  PIPS_BIN_TRIMBANNER,
  PIPS_BIN_AUTO_TRIM,
  PIPS_BIN_AUTO_TRIM_4,
  PIPS_BIN_AUTO_EX, 
  PIPS_BIN_MANUAL,       
  PIPS_BIN_MANUAL_TRIM
};

/* quality level set pattern bits */
enum eQUALITY
{
#if (HIGH_RESOLUTION == 0)

#ifdef USE_360_DRAFT
  PIPS_LV_DRAFT = 10,
  PIPS_LV_STD = 1,
#else
  PIPS_LV_DRAFT = 0,
  PIPS_LV_STD,
#endif /* USE_360_DRAFT */
  PIPS_LV_FINE,
  PIPS_LV_SFINE,
  PIPS_LV_PHOTO,
  PIPS_LV_SPHOTO,

#elif(HIGH_RESOLUTION == 1)

/*   */
#ifdef USE_360_DRAFT
  PIPS_LV_DRAFT = 10,
  PIPS_LV_STD360 = 1,
#else
  PIPS_LV_DRAFT = 0,
  PIPS_LV_STD360,
#endif /* USE_360_DRAFT */
  PIPS_LV_FINE720,
  PIPS_LV_SFINE720,
  PIPS_LV_PHOTO1440,
  PIPS_LV_PHOTO2880,
  PIPS_LV_SPHOTO2880,

#else

/* 2  */
#ifdef USE_360_DRAFT
  PIPS_LV_DRAFT = 10,
  PIPS_LV_STD360 = 1,
#else
  PIPS_LV_DRAFT = 0,
  PIPS_LV_STD360,
#endif /* USE_360_DRAFT */
  PIPS_LV_FINE720,
  PIPS_LV_SFINE720,
  PIPS_LV_PHOTO1440,
  PIPS_LV_PHOTO2880,
  PIPS_LV_SPHOTO1440,
  PIPS_LV_SPHOTO2880,

#endif
  
/* 2003.05 Added */
  PIPS_LV_SILENT

};

/* Ink status */
enum eINK_STATUS
{
  ST_INK_NORMAL = 0,
  ST_INK_LOW,
  ST_INK_END
};

/* Fit to page */
enum eFIT_PAGE
{
	PIPS_FP_OFF = 0,
	PIPS_FP_ON
};

/* Multi page */
enum eMULTI_PAGE
{
	PIPS_MP_1 = 0,
	PIPS_MP_2,
	PIPS_MP_4
};

/* Auto cut */
enum eAUTO_CUT
{
	PIPS_CP_NONE = 0,
	PIPS_CP_1,
	PIPS_CP_2
};

/* Clear ink */
/* bit operation */
enum eCLEAR_INK
{
	PIPS_CI_OFF  = 1,       /* bit 0 */
	PIPS_CI_ON   = 2,	/* bit 1 */
	PIPS_CI_AUTO = 4,	/* bit 2 */
        PIPS_CI_FULL = 8	/* bit 3 */
};


#ifndef __PIPS_DEF_H__
typedef unsigned int UINT;
typedef unsigned short USHORT;
typedef unsigned long ULONG;
typedef unsigned char UCHAR;
typedef struct tagPOINT
{
  long  x;
  long  y;
} POINT, *PPOINT, *LPPOINT;
#endif /* __PIPS_DEF_H__ */

typedef int (*func_t)(UCHAR *, void *, void *, void *);


#endif /* __PIPSDEF_H__ */
